@@ -1,16 +1,12 @@
-package Email::Thread;
-
-=head1 NAME
-
-Email::Thread - Use JWZ's mail threading algorithm with Email::Simple objects
-
-=cut
-
-use Mail::Thread;
 use strict;
-use vars qw( @ISA $VERSION );
-@ISA = qw( Mail::Thread );
-$VERSION = '0.711';
+use warnings;
+package Email::Thread;
+{
+  $Email::Thread::VERSION = '0.712';
+}
+# ABSTRACT: Use JWZ's mail threading algorithm with Email::Simple objects
+
+use parent 'Mail::Thread';
 
 sub _get_hdr {
     my ($class, $msg, $hdr) = @_;
@@ -20,16 +16,27 @@ sub _get_hdr {
 sub _container_class { "Email::Thread::Container" }
 
 package Email::Thread::Container;
-
-use vars qw( @ISA $VERSION );
-@ISA = qw( Mail::Thread::Container );
-$VERSION = $Email::Thread::VERSION;
+{
+  $Email::Thread::Container::VERSION = '0.712';
+}
+use parent -norequire, 'Mail::Thread::Container';
 
 sub header { eval { $_[0]->message->header($_[1]) } }
 
 1;
+
 __END__
 
+=pod
+
+=head1 NAME
+
+Email::Thread - Use JWZ's mail threading algorithm with Email::Simple objects
+
+=head1 VERSION
+
+version 0.712
+
 =head1 SYNOPSIS
 
     use Email::Thread;
@@ -64,24 +71,6 @@ details. Just mentally substitute C<Email::Thread> everywhere you see
 C<Mail::Thread> and C<Email::Thread::Container> where you see
 C<Mail::Thread::Container>.
 
-=head1 PERL EMAIL PROJECT
-
-This module is maintained by the Perl Email Project.
-
-L<http://emailproject.perl.org/wiki/Email::Thread>
-
-=head1 SUPPORT
-
-Support for this module is provided via the CPAN RT system at
-L<http://rt.cpan.org/>
-
-=head1 LICENCE AND COPYRIGHT
-
-Copyright E<copy> Iain Truskett, 2003. All rights reserved.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 THANKS
 
 Simon Cozens (SIMON) for encouraging me to release it, and for
@@ -89,13 +78,19 @@ Email::Simple and Mail::Thread.
 
 Richard Clamp (RCLAMP) for the header patch.
 
-=head1 AUTHORS
-
-Iain Truskett <spoon@cpan.org>
-
 =head1 SEE ALSO
 
 L<perl>, L<Mail::Thread>, L<Email::Simple>
 
-=cut
+=head1 AUTHOR
 
+Iain Truskett <spoon@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2003 by Iain Truskett <spoon@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
